==> cscec5b-storecloud-api-3.0.1-20220816.015131-32-sources.jar: com/ejianc/business/storecloud/vo/WarehouseFlowVO.java <==
package com.ejianc.business.storecloud.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 仓库入出流水表
 *
 * @author generator
 *
 */
public class WarehouseFlowVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String billCode; // 流水单号
    private Date billDate; // 流水日期
    private Long projectId; // 项目ID
    private String projectName; //
    private Long parentOrgId; // 所属组织
    private String parentOrgCode; // 所属组织编码
    private String parentOrgName; //
    private Long orgId; // 所属组织
    private String orgName; //
    private Long storeId; // 仓库
    private String storeName; // 仓库名称
    private Long employeeId; // 业务经办人ID
    private String employeeName; // 业务经办人名称
    private Integer inOutType; // 出入库类型:1-期初入库2-验收入库（河南）3-领料出库4-直接出库
    private String inOutTypeName; // 出入库类型名称
    private Integer inOutFlag; // 出入库属性1入库2出库
    private String storeType; // 仓库属性
    private String storeTypeName; // 仓库属性名称
    private String materialType; // 材料类型
    private String materialTypeName; // 材料类型名称
    private Long materialCategoryId; // 物资分类id
    private String materialCategoryCode; // 物资分类编码
    private String materialCategoryName; // 物资分类名称
    private Long materialId; // 物资id
    private String materialCode; // 物资编码
    private String materialInnerCode; // 物资内码
    private String materialName; // 物资名称
    private String materialSpec; // 规格型号
    private Long materialUnitId; // 计量单位id
    private String materialUnitName; // 计量单位
    private BigDecimal estimatePrice; // 暂估单价(无税)
    private BigDecimal estimateTaxPrice; // 暂估单价
    private BigDecimal price; // 单价(无税)
    private BigDecimal taxPrice; // 单价
    private BigDecimal num; // 数量
    private BigDecimal taxMny; // 金额含税
    private BigDecimal mny; // 金额(无税)
    private BigDecimal tax; // 税额
    private BigDecimal taxRate; // 税率
    private String sourceBillTypeName; // 来源单据类型名称
    private String sourceBillTypeCode; // 来源单据类型编码
    private Long sourceId; // 来源单据id
    private Long sourceDetailId; // 来源单据明细id
    private String sourceBillCode; // 来源单据编码
    private Date sourceBillDate; // 来源单据日期
    private Integer sourceType; // 来源 0-自制,1-订单
    private String cusDef1; // 自定义字段1
    private String cusDef2; // 自定义字段2
    private String cusDef3; // 自定义字段3
    private String cusDef4; // 自定义字段4
    private String cusDef5; // 自定义字段5
    private String cusDef6; // 自定义字段6
    private String cusDef7; // 自定义字段7
    private String cusDef8; // 自定义字段8
    private String cusDef9; // 自定义字段9
    private String cusDef10; // 自定义字段10


    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Date getBillDate() {
        return billDate;
    }

    public void setBillDate(Date billDate) {
        this.billDate = billDate;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getStoreId() {
        return storeId;
    }

    public void setStoreId(Long storeId) {
        this.storeId = storeId;
    }
    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Integer getInOutType() {
        return inOutType;
    }

    public void setInOutType(Integer inOutType) {
        this.inOutType = inOutType;
    }
    public String getInOutTypeName() {
        return inOutTypeName;
    }

    public void setInOutTypeName(String inOutTypeName) {
        this.inOutTypeName = inOutTypeName;
    }
    public Integer getInOutFlag() {
        return inOutFlag;
    }

    public void setInOutFlag(Integer inOutFlag) {
        this.inOutFlag = inOutFlag;
    }
    public String getStoreType() {
        return storeType;
    }

    public void setStoreType(String storeType) {
        this.storeType = storeType;
    }
    public String getStoreTypeName() {
        return storeTypeName;
    }

    public void setStoreTypeName(String storeTypeName) {
        this.storeTypeName = storeTypeName;
    }
    public String getMaterialType() {
        return materialType;
    }

    public void setMaterialType(String materialType) {
        this.materialType = materialType;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryCode() {
        return materialCategoryCode;
    }

    public void setMaterialCategoryCode(String materialCategoryCode) {
        this.materialCategoryCode = materialCategoryCode;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialInnerCode() {
        return materialInnerCode;
    }

    public void setMaterialInnerCode(String materialInnerCode) {
        this.materialInnerCode = materialInnerCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public Long getMaterialUnitId() {
        return materialUnitId;
    }

    public void setMaterialUnitId(Long materialUnitId) {
        this.materialUnitId = materialUnitId;
    }
    public String getMaterialUnitName() {
        return materialUnitName;
    }

    public void setMaterialUnitName(String materialUnitName) {
        this.materialUnitName = materialUnitName;
    }
    public BigDecimal getEstimatePrice() {
        return estimatePrice;
    }

    public void setEstimatePrice(BigDecimal estimatePrice) {
        this.estimatePrice = estimatePrice;
    }
    public BigDecimal getEstimateTaxPrice() {
        return estimateTaxPrice;
    }

    public void setEstimateTaxPrice(BigDecimal estimateTaxPrice) {
        this.estimateTaxPrice = estimateTaxPrice;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public String getSourceBillTypeName() {
        return sourceBillTypeName;
    }

    public void setSourceBillTypeName(String sourceBillTypeName) {
        this.sourceBillTypeName = sourceBillTypeName;
    }
    public String getSourceBillTypeCode() {
        return sourceBillTypeCode;
    }

    public void setSourceBillTypeCode(String sourceBillTypeCode) {
        this.sourceBillTypeCode = sourceBillTypeCode;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public String getSourceBillCode() {
        return sourceBillCode;
    }

    public void setSourceBillCode(String sourceBillCode) {
        this.sourceBillCode = sourceBillCode;
    }
    public Date getSourceBillDate() {
        return sourceBillDate;
    }

    public void setSourceBillDate(Date sourceBillDate) {
        this.sourceBillDate = sourceBillDate;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    public String getCusDef1() {
        return cusDef1;
    }

    public void setCusDef1(String cusDef1) {
        this.cusDef1 = cusDef1;
    }
    public String getCusDef2() {
        return cusDef2;
    }

    public void setCusDef2(String cusDef2) {
        this.cusDef2 = cusDef2;
    }
    public String getCusDef3() {
        return cusDef3;
    }

    public void setCusDef3(String cusDef3) {
        this.cusDef3 = cusDef3;
    }
    public String getCusDef4() {
        return cusDef4;
    }

    public void setCusDef4(String cusDef4) {
        this.cusDef4 = cusDef4;
    }
    public String getCusDef5() {
        return cusDef5;
    }

    public void setCusDef5(String cusDef5) {
        this.cusDef5 = cusDef5;
    }
    public String getCusDef6() {
        return cusDef6;
    }

    public void setCusDef6(String cusDef6) {
        this.cusDef6 = cusDef6;
    }
    public String getCusDef7() {
        return cusDef7;
    }

    public void setCusDef7(String cusDef7) {
        this.cusDef7 = cusDef7;
    }
    public String getCusDef8() {
        return cusDef8;
    }

    public void setCusDef8(String cusDef8) {
        this.cusDef8 = cusDef8;
    }
    public String getCusDef9() {
        return cusDef9;
    }

    public void setCusDef9(String cusDef9) {
        this.cusDef9 = cusDef9;
    }
    public String getCusDef10() {
        return cusDef10;
    }

    public void setCusDef10(String cusDef10) {
        this.cusDef10 = cusDef10;
    }

}

==> cscec5b-storecloud-api-3.0.1-20221124.104206-215-sources.jar: com/ejianc/business/storecloud/vo/WarehouseFlowVO.java <==
package com.ejianc.business.storecloud.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 仓库入出流水表
 *
 * @author generator
 *
 */
public class WarehouseFlowVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String billCode; // 流水单号
    private Date billDate; // 流水日期
    private Long projectId; // 项目ID
    private String projectName; //
    private Long parentOrgId; // 所属组织
    private String parentOrgCode; // 所属组织编码
    private String parentOrgName; //
    private Long orgId; // 所属组织
    private String orgName; //
    private Long storeId; // 仓库
    private String storeName; // 仓库名称
    private Long employeeId; // 业务经办人ID
    private String employeeName; // 业务经办人名称
    private Integer inOutType; // 出入库类型:1-期初入库2-验收入库（河南）3-领料出库4-直接出库
    private String inOutTypeName; // 出入库类型名称
    private Integer inOutFlag; // 出入库属性1入库2出库
    private String storeType; // 仓库属性
    private String storeTypeName; // 仓库属性名称
    private String materialType; // 材料类型
    private String materialTypeName; // 材料类型名称
    private Long materialCategoryId; // 物资分类id
    private String materialCategoryCode; // 物资分类编码
    private String materialCategoryName; // 物资分类名称
    private Long materialId; // 物资id
    private String materialCode; // 物资编码
    private String materialInnerCode; // 物资内码
    private String materialName; // 物资名称
    private String materialSpec; // 规格型号
    private Long materialUnitId; // 计量单位id
    private String materialUnitName; // 计量单位
    private BigDecimal estimatePrice; // 暂估单价(无税)
    private BigDecimal estimateTaxPrice; // 暂估单价
    private BigDecimal price; // 单价(无税)
    private BigDecimal taxPrice; // 单价
    private BigDecimal num; // 数量
    private BigDecimal taxMny; // 金额含税
    private BigDecimal mny; // 金额(无税)
    private BigDecimal tax; // 税额
    private BigDecimal taxRate; // 税率
    private String sourceBillTypeName; // 来源单据类型名称
    private String sourceBillTypeCode; // 来源单据类型编码
    private Long sourceId; // 来源单据id
    private Long sourceDetailId; // 来源单据明细id
    private String sourceBillCode; // 来源单据编码
    @JsonFormat(
            pattern = "yyyy-MM-dd",
            timezone = "GMT+8"
    )
    private Date sourceBillDate; // 来源单据日期
    private Integer sourceType; // 来源 0-自制,1-订单
    private String cusDef1; // 自定义字段1
    private String cusDef2; // 自定义字段2
    private String cusDef3; // 自定义字段3
    private String cusDef4; // 自定义字段4
    private String cusDef5; // 自定义字段5
    private String cusDef6; // 自定义字段6
    private String cusDef7; // 自定义字段7
    private String cusDef8; // 自定义字段8
    private String cusDef9; // 自定义字段9
    private String cusDef10; // 自定义字段10
    private BigDecimal outNum; // 出库数量
    private BigDecimal outTaxMny; // 出库金额
    private BigDecimal surplusNum; // 结存量
    private String supplyName; // 分包单位名称
    private String contractName; // 合同名称
    private String supplierName; // 供应商名称


    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Date getBillDate() {
        return billDate;
    }

    public void setBillDate(Date billDate) {
        this.billDate = billDate;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getStoreId() {
        return storeId;
    }

    public void setStoreId(Long storeId) {
        this.storeId = storeId;
    }
    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Integer getInOutType() {
        return inOutType;
    }

    public void setInOutType(Integer inOutType) {
        this.inOutType = inOutType;
    }
    public String getInOutTypeName() {
        return inOutTypeName;
    }

    public void setInOutTypeName(String inOutTypeName) {
        this.inOutTypeName = inOutTypeName;
    }
    public Integer getInOutFlag() {
        return inOutFlag;
    }

    public void setInOutFlag(Integer inOutFlag) {
        this.inOutFlag = inOutFlag;
    }
    public String getStoreType() {
        return storeType;
    }

    public void setStoreType(String storeType) {
        this.storeType = storeType;
    }
    public String getStoreTypeName() {
        return storeTypeName;
    }

    public void setStoreTypeName(String storeTypeName) {
        this.storeTypeName = storeTypeName;
    }
    public String getMaterialType() {
        return materialType;
    }

    public void setMaterialType(String materialType) {
        this.materialType = materialType;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryCode() {
        return materialCategoryCode;
    }

    public void setMaterialCategoryCode(String materialCategoryCode) {
        this.materialCategoryCode = materialCategoryCode;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialInnerCode() {
        return materialInnerCode;
    }

    public void setMaterialInnerCode(String materialInnerCode) {
        this.materialInnerCode = materialInnerCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public Long getMaterialUnitId() {
        return materialUnitId;
    }

    public void setMaterialUnitId(Long materialUnitId) {
        this.materialUnitId = materialUnitId;
    }
    public String getMaterialUnitName() {
        return materialUnitName;
    }

    public void setMaterialUnitName(String materialUnitName) {
        this.materialUnitName = materialUnitName;
    }
    public BigDecimal getEstimatePrice() {
        return estimatePrice;
    }

    public void setEstimatePrice(BigDecimal estimatePrice) {
        this.estimatePrice = estimatePrice;
    }
    public BigDecimal getEstimateTaxPrice() {
        return estimateTaxPrice;
    }

    public void setEstimateTaxPrice(BigDecimal estimateTaxPrice) {
        this.estimateTaxPrice = estimateTaxPrice;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public String getSourceBillTypeName() {
        return sourceBillTypeName;
    }

    public void setSourceBillTypeName(String sourceBillTypeName) {
        this.sourceBillTypeName = sourceBillTypeName;
    }
    public String getSourceBillTypeCode() {
        return sourceBillTypeCode;
    }

    public void setSourceBillTypeCode(String sourceBillTypeCode) {
        this.sourceBillTypeCode = sourceBillTypeCode;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public String getSourceBillCode() {
        return sourceBillCode;
    }

    public void setSourceBillCode(String sourceBillCode) {
        this.sourceBillCode = sourceBillCode;
    }
    public Date getSourceBillDate() {
        return sourceBillDate;
    }

    public void setSourceBillDate(Date sourceBillDate) {
        this.sourceBillDate = sourceBillDate;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    public String getCusDef1() {
        return cusDef1;
    }

    public void setCusDef1(String cusDef1) {
        this.cusDef1 = cusDef1;
    }
    public String getCusDef2() {
        return cusDef2;
    }

    public void setCusDef2(String cusDef2) {
        this.cusDef2 = cusDef2;
    }
    public String getCusDef3() {
        return cusDef3;
    }

    public void setCusDef3(String cusDef3) {
        this.cusDef3 = cusDef3;
    }
    public String getCusDef4() {
        return cusDef4;
    }

    public void setCusDef4(String cusDef4) {
        this.cusDef4 = cusDef4;
    }
    public String getCusDef5() {
        return cusDef5;
    }

    public void setCusDef5(String cusDef5) {
        this.cusDef5 = cusDef5;
    }
    public String getCusDef6() {
        return cusDef6;
    }

    public void setCusDef6(String cusDef6) {
        this.cusDef6 = cusDef6;
    }
    public String getCusDef7() {
        return cusDef7;
    }

    public void setCusDef7(String cusDef7) {
        this.cusDef7 = cusDef7;
    }
    public String getCusDef8() {
        return cusDef8;
    }

    public void setCusDef8(String cusDef8) {
        this.cusDef8 = cusDef8;
    }
    public String getCusDef9() {
        return cusDef9;
    }

    public void setCusDef9(String cusDef9) {
        this.cusDef9 = cusDef9;
    }
    public String getCusDef10() {
        return cusDef10;
    }

    public void setCusDef10(String cusDef10) {
        this.cusDef10 = cusDef10;
    }

    public BigDecimal getOutNum() {
        return outNum;
    }

    public void setOutNum(BigDecimal outNum) {
        this.outNum = outNum;
    }

    public BigDecimal getOutTaxMny() {
        return outTaxMny;
    }

    public void setOutTaxMny(BigDecimal outTaxMny) {
        this.outTaxMny = outTaxMny;
    }

    public BigDecimal getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(BigDecimal surplusNum) {
        this.surplusNum = surplusNum;
    }

    public String getSupplyName() {
        return supplyName;
    }

    public void setSupplyName(String supplyName) {
        this.supplyName = supplyName;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
}
